import datetime

time_str_format = ['%Y-%m-%d %H:%M:%S.%f',
                   '%Y-%m-%d %H:%M:%S',
                   '%Y-%m-%d',
                   '%Y-%m-%dT%H:%M:%S.%f',
                   '%Y-%m-%dT%H:%M:%S']


def str2timestamp(time_str):
    try:
        return int(time_str)
    except:

        for str_f in time_str_format:
            try:
                date_time_obj = datetime.datetime.strptime(time_str, str_f)
                return int(date_time_obj.timestamp() * 1000)
            except:
                continue
    raise Exception('format time error')


def timestamp_ms2str(timestamp_ms):
    dt_object = datetime.datetime.fromtimestamp(timestamp_ms / 1000.0)

    # 格式化datetime对象为指定格式
    formatted_date = dt_object.strftime('%Y-%m-%d %H:%M:%S.%f')[:-3]

    return formatted_date


def ms_to_str(milliseconds, split_char=':'):
    milliseconds = int(milliseconds)
    seconds, milliseconds = divmod(milliseconds, 1000)
    minutes, seconds = divmod(seconds, 60)
    hours, minutes = divmod(minutes, 60)

    return f"{hours:02d}{split_char}{minutes:02d}{split_char}{seconds:02d}.{milliseconds:03d}"



__title__ = "py-tools-wd"
__description__ = "wd py tools"
__url__ = "https://github.com/pgcomb/wd_tools_py"
__version__ = "0.1.12"
# __build__ = 0x023202
__author__ = ["Wang Dongxu", "Ma xiaohui"]
__author_email__ = ["wangdongxudyx@163.com", ""]
__license__ = "Apache-2.0"
# __copyright__ = "Copyright Kenneth Reitz"
# __cake__ = "\u2728 \U0001f370 \u2728"



#!/usr/bin/env python
import os
import sys
from codecs import open

from setuptools import setup

CURRENT_PYTHON = sys.version_info[:2]
REQUIRED_PYTHON = (3, 8)

if CURRENT_PYTHON < REQUIRED_PYTHON:
    sys.stderr.write(
        """
==========================
Unsupported Python version
==========================
This version of Requests requires at least Python {}.{}, but
you're trying to install it on Python {}.{}. To resolve this,
consider upgrading to a supported Python version.

If you can't upgrade your Python version, you'll need to
pin to an older version of Requests (<2.32.0).
""".format(
            *(REQUIRED_PYTHON + CURRENT_PYTHON)
        )
    )
    sys.exit(1)

# 'setup.py publish' shortcut.
if sys.argv[-1] == "publish":
    os.system("python setup.py sdist bdist_wheel")
    os.system("twine upload dist/*")
    sys.exit()

requires = [

]
test_requirements = [

]

about = {}
here = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(here, "src", "py_tools_wd", "__version__.py"), "r", "utf-8") as f:
    exec(f.read(), about)

with open("README.md", "r", "utf-8") as f:
    readme = f.read()

setup(
    name=about["__title__"],
    version=about["__version__"],
    description=about["__description__"],
    long_description=readme,
    long_description_content_type="text/markdown",
    author=about["__author__"],
    author_email=about["__author_email__"],
    url=about["__url__"],
    packages=["py_tools_wd/image", "py_tools_wd/mq","py_tools_wd/base","py_tools_wd/ai"],
    package_data={"": ["LICENSE", "NOTICE"]},
    package_dir={"": "src"},
    include_package_data=True,
    python_requires=">=3.8",
    install_requires=requires,
    license=about["__license__"],
    zip_safe=False,
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        # "Environment :: Web Environment",
        # "Intended Audience :: Developers",
        "License :: OSI Approved :: Apache Software License",
        # "Natural Language :: English",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Programming Language :: Python :: 3 :: Only",
        # "Programming Language :: Python :: Implementation :: CPython",
        # "Programming Language :: Python :: Implementation :: PyPy",
        # "Topic :: Internet :: WWW/HTTP",
        # "Topic :: Software Development :: Libraries",
    ],
    # cmdclass={"test": PyTest},
    tests_require=test_requirements,
    extras_require={
        # "security": [],
        # "socks": ["PySocks>=1.5.6, !=1.5.7"],
        # "use_chardet_on_py3": ["chardet>=3.0.2,<6"],
    },
    project_urls={
        # "Documentation": "https://requests.readthedocs.io",
        # "Source": "https://github.com/psf/requests",
    },
)
